import React, { useEffect } from "react";
import { Paper, Grid, useTheme, makeStyles } from "@material-ui/core";
import { useStatistics } from "../../api/SwaggerApi";
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { RootContainer } from "../../components/common/Container/RootContainer";
import ActiveIOCChart from "../../components/statistics/ActiveIOCChart";
import DeploymentLineChart from "../../components/statistics/DeploymentLineChart";
import { useActiveIOCHistory, useDeployedIOCStatistics } from '../../api/SwaggerApi';
import { PrimeKeyValueTable } from "../../components/common/PrimeKeyValueTable/PrimeKeyValueTable";

const useStyles = makeStyles((theme) => ({
    paper: {
        padding: theme.spacing(4),
    },
}));

export function StatisticsView() {

    const classes = useStyles();

    const title = "Statistics";
    useGlobalAppBar(title);

    const [statistics, getStatistics] = useStatistics();

    useEffect(() =>
        getStatistics()
        , [getStatistics]
    );

    let prometheusStats = null;
    let dbStats = null;

    //rename "response fields" into readable format
    if (statistics) {
        prometheusStats = {
            "IOCs detected on ESS control networks": statistics.numberOfActiveIocs,
            "IOC hosts reachable on all ESS control networks": statistics.numberOfActiveHosts,
            "IOC hosts reachable on the technical network": statistics.numberOfIocHostsOnTechnicalNetwork,
            "Number of IOC hosts which are unreachable or have issues": statistics.numberOfHostsWithIssue,
        }

        dbStats = {
            "Registered IOCs": statistics.numberOfCreatedIocs,
            "Currently deployed IOCs": statistics.numberOfActiveDeployments,
            "Number of hosts running IOCs": statistics.numberOfIocHostsWithIocsDeployed,
            "Total number of deployment jobs executed": statistics.numberOfDeployments,
        }
    }

    const theme = useTheme();

    return (
        <RootContainer>
            <Grid container direction="column" spacing={theme.spacing(0.5)}>
                {statistics &&
                    <>
                        <Grid item xs={12}>
                            <h2>Statistics</h2>
                            <PrimeKeyValueTable obj={prometheusStats} labels={["Network monitoring"]} />
                        </Grid>
                        <Grid item xs={12}>
                            <PrimeKeyValueTable obj={dbStats} labels={["According to the deployment tool"]} />
                        </Grid>
                        <Grid item xs={12}>
                            <PrimeKeyValueTable obj={statistics.networkScopesIocCount} labels={["IOCs per network scope according to the deployment tool"]} />
                        </Grid>
                    </>
                }

                <Grid item xs={12}>
                    <Paper className={classes.paper}>
                        <DeploymentLineChart title="Successful deployments over time by the deployment tool" chartLabel="Deployed IOCs in time" hook={useDeployedIOCStatistics} />
                    </Paper>
                </Grid>
                <Grid item xs={12}>
                    <Paper className={classes.paper}>
                        <ActiveIOCChart title="Number of IOCs currently detected on each ESS control network" />
                    </Paper>
                </Grid>
                <Grid item xs={12}>
                    <Paper className={classes.paper}>
                        <DeploymentLineChart title="Number of IOCs detected on ESS networks over time" chartLabel="Active IOCs over time" hook={useActiveIOCHistory} />
                    </Paper>
                </Grid>
            </Grid>

        </RootContainer>
    )
}
